Learn R Programming

lidR (version 1.4.2)

lasroi: Select a region of interest interactively

Description

Select a rectangular region of interest interactively using the mouse

Usage

lasroi(.las, ...)

Arguments

.las

An object of class LAS

…

Optional parameters for the plot function

Value

An object of class LAS

Details

lasroi enables the user to select a region of interest (ROI) by drawing a rectangle with the mouse

Examples

Run this code
# NOT RUN {
LASfile <- system.file("extdata", "Megaplot.laz", package="lidR")
lidar = readLAS(LASfile)

subset = lasroi(lidar)
# }

Run the code above in your browser using DataLab